pub enum Frame {
Event(EventFrame),
Response(Response),
}Expand description
One line read from the daemon, which is either a response or a pushed event.
Events are tried first: an event line has an event field and no response has one.
Variants
Event(EventFrame)
Response(Response)